@@ -64,7 +64,7 @@ PropType ethernet_properties[] = {
   { "auto", TYPE_BOOLEAN },
   { "active", TYPE_BOOLEAN },
   { "configured", TYPE_BOOLEAN },
-  { "config-method", TYPE_INT },
+  { "config-method", TYPE_STRING },
   { "ip-address", TYPE_STRING },
   { "ip-mask", TYPE_STRING },
   { "gateway-address", TYPE_STRING },
@@ -79,7 +79,8 @@ PropType wireless_properties[] = {
   { "configured", TYPE_BOOLEAN },
   { "essid", TYPE_STRING },
   { "key", TYPE_STRING },
-  { "key-type", TYPE_INT },
+  { "key-type", TYPE_STRING },
+  { "config-method", TYPE_STRING },
   { "ip_address", TYPE_STRING },
   { "ip_mask", TYPE_STRING },
   { "gateway-address", TYPE_STRING },
@@ -273,9 +274,10 @@ get_location_key_file (GstNetworkLocations *locations,
   if (!g_key_file_load_from_file (key_file, path, 0, NULL))
     {
       g_key_file_free (key_file);
-      return NULL;
+      key_file =  NULL;
     }
 
+  g_free (path);
   return key_file;
 }
 
@@ -283,16 +285,12 @@ static GList*
 array_to_list (const gchar **str_list)
 {
   GList *list = NULL;
-  gchar **pos = (gchar**) str_list;
+  gint i;
 
-  while (*pos)
-    {
-      list = g_list_prepend (list, g_strdup (*pos));
-      pos++;
-    }
+  for (i = 0; str_list[i]; i++)
+    list = g_list_prepend (list, g_strdup (str_list[i]));
 
-  list = g_list_reverse (list);
-  return list;
+  return g_list_reverse (list);
 }
 
 static gboolean
@@ -357,8 +355,9 @@ static gboolean
 compare_static_host (const gchar    *str,
 		     OobsStaticHost *static_host)
 {
-  gchar **split, *ip_address;
-  GList *list1, *list2;
+  gchar **split;
+  const gchar *ip_address;
+  GList *list1, *list2 = NULL;
   gboolean equal = TRUE;
 
   split = g_strsplit (str, ";", -1);
@@ -385,27 +384,28 @@ static gboolean
 compare_static_hosts (OobsHostsConfig *hosts_config,
 		      GKeyFile        *key_file)
 {
-  gchar **str_list, **elem;
+  gchar **str_list;
   OobsList *static_hosts;
   OobsListIter iter;
   OobsStaticHost *static_host;
   gboolean valid, equal = TRUE;
+  gint i = 0;
 
-  elem = str_list = g_key_file_get_string_list (key_file, "general", "static-hosts", NULL, NULL);
+  str_list = g_key_file_get_string_list (key_file, "general", "static-hosts", NULL, NULL);
   static_hosts = oobs_hosts_config_get_static_hosts (hosts_config);
   valid = oobs_list_get_iter_first (static_hosts, &iter);
 
-  while (*elem && valid && equal)
+  while (str_list[i] && valid && equal)
     {
       static_host = OOBS_STATIC_HOST (oobs_list_get (static_hosts, &iter));
-      equal = compare_static_host (*elem, static_host);
+      equal = compare_static_host (str_list[i], static_host);
       g_object_unref (static_host);
 
       valid = oobs_list_iter_next (static_hosts, &iter);
-      elem++;
+      i++;
     }
 
-  if (*elem || valid)
+  if (str_list[i] || valid)
     equal = FALSE;
 
   g_strfreev (str_list);
@@ -455,6 +455,44 @@ compare_hosts_config (OobsHostsConfig *hosts_config,
   return TRUE;
 }
 
+/* code to support/migrate legacy parameters */
+static void
+migrate_old_parameters (GKeyFile    *key_file,
+			const gchar *section,
+			const gchar *key)
+{
+  GError *error = NULL;
+  gint value;
+  gchar *config_method_options[] = { "none", "static", "dhcp" };
+  gchar *key_type_options[] = { "wep-ascii", "wep-hex" };
+  gchar **values = NULL;
+
+  if (strcmp (key, "config-method") == 0)
+    values = config_method_options;
+  else if (strcmp (key, "key-type") == 0)
+    values = key_type_options;
+  else
+    {
+      /* no need to continue */
+      return;
+    }
+
+  value = g_key_file_get_integer (key_file, section, key, &error);
+
+  if (error)
+    return;
+
+  /* sanity check */
+  if ((values == config_method_options && (value < 0 || value > 2)) ||
+      (values == key_type_options && (value < 0 || value > 1)))
+    {
+      g_critical ("Incorrect value %d in old value for key '%s'", value, key);
+      return;
+    }
+
+  g_key_file_set_string (key_file, section, key, values[value]);
+}
+
 static gboolean
 compare_interface (GObject  *iface,
 		   PropType  props[],
@@ -468,6 +506,8 @@ compare_interface (GObject  *iface,
 
   while (props[i].key && equal)
     {
+      migrate_old_parameters (key_file, name, props[i].key);
+
       if (props[i].type == TYPE_STRING)
 	{
 	  value1 = g_key_file_get_string (key_file, name, props[i].key, NULL);
@@ -483,12 +523,14 @@ compare_interface (GObject  *iface,
 	  g_object_get (iface, props[i].key, &int_value2, NULL);
 	  equal = (int_value1 == int_value2);
 	}
-      else
+      else if (props[i].type == TYPE_BOOLEAN)
 	{
 	  bool_value1 = g_key_file_get_boolean (key_file, name, props[i].key, NULL);
 	  g_object_get (iface, props[i].key, &bool_value2, NULL);
 	  equal = ((bool_value1 == TRUE) == (bool_value2 == TRUE));
 	}
+      else
+	g_assert_not_reached ();
 
       i++;
     }
@@ -547,6 +589,7 @@ compare_location (GstNetworkLocations *locations,
 {
   GstNetworkLocationsPrivate *priv;
   GKeyFile *key_file;
+  gboolean equal;
 
   priv = (GstNetworkLocationsPrivate *) locations->_priv;
   key_file = get_location_key_file (locations, name);
@@ -554,15 +597,11 @@ compare_location (GstNetworkLocations *locations,
   if (!key_file)
     return FALSE;
 
-  if (compare_hosts_config (OOBS_HOSTS_CONFIG (locations->hosts_config), key_file) &&
-      compare_interfaces (OOBS_IFACES_CONFIG (locations->ifaces_config), key_file))
-    {
-      g_key_file_free (key_file);
-      return TRUE;
-    }
+  equal = (compare_hosts_config (OOBS_HOSTS_CONFIG (locations->hosts_config), key_file) &&
+	   compare_interfaces (OOBS_IFACES_CONFIG (locations->ifaces_config), key_file));
 
   g_key_file_free (key_file);
-  return FALSE;
+  return equal;
 }
 
 gchar*
@@ -665,6 +704,8 @@ set_interface (GObject  *iface,
 
   while (props[i].key)
     {
+      migrate_old_parameters (key_file, name, props[i].key);
+
       if (props[i].type == TYPE_STRING)
 	{
 	  value = g_key_file_get_string (key_file, name, props[i].key, NULL);
